%define upstream_name    Test-LeakTrace
%define upstream_version 0.17

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 9

Summary:    A LeakTrace interface for whole scripts
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Test/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Exporter) >= 5.570.0
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Test::More) >= 0.620.0
BuildRequires: perl-devel
# Don't provide private perl libs
%{?perl_default_filter}

%description
'Test::LeakTrace' provides several functions that trace memory leaks. This
module scans arenas, the memory allocation system, so it can detect any
leaked SVs in given blocks.

*Leaked SVs* are SVs which are not released after the end of the scope they
have been created. These SVs include global variables and internal caches.
For example, if you call a method in a tracing block, perl might prepare a
cache for the method. Thus, to trace true leaks, 'no_leaks_ok()' and
'leaks_cmp_ok()' executes a block more than once.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README example
%{_mandir}/man3/*
%perl_vendorarch/*


%changelog
* Fri Aug 23 2024 neoclust <neoclust> 0.170.0-9.mga10
+ Revision: 2089525
- Rebuild on the Real BS
- Rebuild against new perl
- Rebuild against new perl

* Wed Nov 29 2023 tv <tv> 0.170.0-6.mga10
+ Revision: 2011120
- Rebuild for perl-5.38

* Tue Jun 07 2022 umeabot <umeabot> 0.170.0-5.mga9
+ Revision: 1862235
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 0.170.0-4.mga9
+ Revision: 1795413
- Mageia 9 Mass Rebuild

* Mon May 24 2021 tmb <tmb> 0.170.0-3.mga9
+ Revision: 1726220
- rebuild post bootstrap
- rebuild for perl-5.34.0

* Thu Feb 25 2021 tv <tv> 0.170.0-1.mga9
+ Revision: 1690372
- update to 0.17

* Wed Jun 17 2020 pterjan <pterjan> 0.160.0-11.mga8
+ Revision: 1594122
- Clean rebuild
- Clean rebuild

* Sat Feb 15 2020 umeabot <umeabot> 0.160.0-9.mga8
+ Revision: 1528678
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Mon Aug 26 2019 tv <tv> 0.160.0-8.mga8
+ Revision: 1432463
- rebuild with perl-5.30 on BS (for missing signature)
+ tmb <tmb>
- rebuild for perl-5.30.0-4.mga8

* Fri Sep 21 2018 umeabot <umeabot> 0.160.0-6.mga7
+ Revision: 1293875
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 pterjan <pterjan> 0.160.0-5.mga7
+ Revision: 1250541
- Rebuild cleanly
- Fix file list

* Tue Oct 03 2017 tv <tv> 0.160.0-3.mga7
+ Revision: 1166796
- rebuild with fixed rpm for missing autodeps

* Tue Sep 05 2017 tv <tv> 0.160.0-2.mga7
+ Revision: 1151369
- rebuild with fixed perl

* Sun Jul 23 2017 shlomif <shlomif> 0.160.0-1.mga7
+ Revision: 1128968
- update to 0.16

* Sat Jul 22 2017 neoclust <neoclust> 0.150.0-7.mga7
+ Revision: 1127588
- Rebuild against new Perl 5.26

* Fri Jul 21 2017 tv <tv> 0.150.0-6.mga7
+ Revision: 1126401
- BR perl(Module::Install)
- rebuild for perl 5.26

* Fri Jul 21 2017 neoclust <neoclust> 0.150.0-5.mga7
+ Revision: 1126305
- Rebuild against new perl

* Sun Jun 19 2016 pterjan <pterjan> 0.150.0-4.mga6
+ Revision: 1034307
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.150.0-3.mga6
+ Revision: 958076
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 0.150.0-2.mga6
+ Revision: 845311
- rebuild for soname-ifed perl

* Tue Jun 23 2015 sander85 <sander85> 0.150.0-1.mga6
+ Revision: 840460
- update to 0.15

* Sat Oct 18 2014 umeabot <umeabot> 0.140.0-10.mga5
+ Revision: 787821
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.140.0-9.mga5
+ Revision: 741139
- Second Mageia 5 Mass Rebuild

* Thu Oct 02 2014 tv <tv> 0.140.0-8.mga5
+ Revision: 736010
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.140.0-7.mga5
+ Revision: 686471
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 0.140.0-6.mga5
+ Revision: 631744
- Rebuild for perl 5.20

* Sat Oct 19 2013 umeabot <umeabot> 0.140.0-5.mga4
+ Revision: 524524
- Mageia 4 Mass Rebuild

* Wed May 29 2013 jquelin <jquelin> 0.140.0-4.mga4
+ Revision: 430970
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.140.0-3.mga3
+ Revision: 373570
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 0.140.0-2.mga3
+ Revision: 251202
- rebuild for perl 5.16

* Fri Oct 14 2011 jquelin <jquelin> 0.140.0-1.mga2
+ Revision: 154860
- update to 0.14

* Thu Jun 30 2011 jquelin <jquelin> 0.130.0-1.mga2
+ Revision: 116570
- imported package perl-Test-LeakTrace


* Thu Jun 30 2011 cpan2dist 0.13-1mga
- initial mageia release, generated with cpan2dist
